@@ -2,6 +2,8 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
+// @dart = 2.6
+
 /// This library defines runtime operations on objects used by the code
 /// generator.
 part of dart._runtime;
@@ -372,13 +374,6 @@ replNameLookup(object, field) => JS('', '''(() => {
   return rawField;
 })()''');
 
-// TODO(jmesserly): the debugger extension hardcodes a call to this private
-// function. Fix that.
-@Deprecated('use replNameLookup')
-_dhelperRepl(obj, field, Function(Object) callback) {
-  return callback(replNameLookup(obj, field));
-}
-
 /// Shared code for dsend, dindex, and dsetindex.
 callMethod(obj, name, typeArgs, args, named, displayName) {
   if (JS('!', 'typeof # == "function" && # == "call"', obj, name)) {
